@@ -6,6 +6,7 @@ import struct
 from contextlib import contextmanager
 from contextlib import suppress
 from typing import Any
+from typing import Counter as CounterType
 from typing import Iterable
 from typing import Iterator
 from typing import MutableSet
@@ -14,9 +15,7 @@ from typing import Sequence
 from typing import Type
 from typing import Union
 from typing import overload
-from warnings import warn
 
-from packaging.version import Version
 from shapely.geometry import shape
 from shapely.geometry.base import BaseGeometry
 
@@ -26,7 +25,7 @@ from paquo.classes import QuPathPathClass
 from paquo.java import GsonTools
 from paquo.java import IllegalArgumentException
 from paquo.java import PathObjectHierarchy
-from paquo.java import qupath_version
+from paquo.java import compatibility
 from paquo.pathobjects import PathROIObjectType
 from paquo.pathobjects import QuPathPathAnnotationObject
 from paquo.pathobjects import QuPathPathDetectionObject
@@ -89,12 +88,12 @@ class PathObjectProxy(Sequence[PathROIObjectType], MutableSet[PathROIObjectType]
         with suppress(KeyError):
             del self.__dict__["_list"]
 
-    def _disabled(self, other: Any) -> Any:
+    def _disabled(self, other: Iterable[Any]) -> "PathObjectProxy":
         raise NotImplementedError(f"{type(self).__name__} only supports inplace operations: '|=', '-='")
-    __and__ = __or__ = __sub__ = __xor__ = __iand__ = __ixor__ = _disabled
+    __or__ = __and__ = __sub__ = __xor__ = __iand__ = __ixor__ = _disabled
     del _disabled
 
-    def __ior__(self, other: Any) -> "PathObjectProxy":  # type: ignore
+    def __ior__(self, other: Iterable[Any]) -> "PathObjectProxy":  # type: ignore
         if self._mask:
             raise IOError("cannot modify view")
         if self._readonly:
@@ -107,7 +106,7 @@ class PathObjectProxy(Sequence[PathROIObjectType], MutableSet[PathROIObjectType]
         return self
     update = __ior__
 
-    def __isub__(self, other: Iterable[PathROIObjectType]) -> "PathObjectProxy":  # type: ignore
+    def __isub__(self, other: Iterable[Any]) -> "PathObjectProxy":  # type: ignore
         if self._mask:
             raise IOError("cannot modify view")
         if self._readonly:
@@ -210,6 +209,9 @@ class PathObjectProxy(Sequence[PathROIObjectType], MutableSet[PathROIObjectType]
                 mask = [self._mask[idx] for idx in i]
             return PathObjectProxy(self._hierarchy, self._paquo_cls, mask)
 
+    def count(self, value: PathROIObjectType) -> int:
+        return int(value in self)  # PathObjectProxy is a set
+
     def __repr__(self):
         c = type(self).__name__
         h = repr(self._hierarchy)
@@ -379,7 +381,7 @@ class QuPathPathObjectHierarchy:
             raise TypeError("requires a geojson list")
 
         aos = []
-        skipped = collections.Counter()  # type: ignore
+        skipped: "CounterType[str]" = collections.Counter()
         for annotation in geojson:
             try:
                 if fix_invalid:
@@ -397,7 +399,10 @@ class QuPathPathObjectHierarchy:
                 # todo: should maybe test at the beginning of this method
                 #   if the version supports id or not, instead of checking
                 #   the version number...
-                if qupath_version and qupath_version <= Version("0.2.3") and 'id' not in annotation:
+                if (
+                    compatibility.requires_annotation_json_fix()
+                    and 'id' not in annotation
+                ):
                     object_type = annotation['properties'].get("object_type", "unknown")
                     object_id = {
                         'annotation': "PathAnnotationObject",
@@ -607,7 +612,7 @@ class QuPathPathObjectHierarchy:
             ome.rois.append(roi)
             ome.structured_annotations.append(map_annotation)
 
-        return to_xml(ome)  # type: ignore
+        return to_xml(ome)
 
     def __repr__(self):
         return f"Hierarchy(image={self._image_name}, annotations={len(self._annotations)}, detections={len(self._detections)})"
