@@ -7,15 +7,21 @@ from contextlib import contextmanager
 from itertools import chain
 from pathlib import Path
 from textwrap import dedent
-from typing import Tuple, List, Optional, Callable, Union, Iterable, Any, Dict
+from typing import Any
+from typing import Callable
+from typing import ContextManager
+from typing import Dict
+from typing import Iterable
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import Union
 from warnings import warn
 
 import jpype
-from packaging.version import parse
-from packaging.version import Version
-from packaging.version import LegacyVersion
 
 from paquo._utils import nullcontext
+from paquo._utils import QuPathVersion
 
 # types
 PathOrStr = Union[Path, str]
@@ -142,13 +148,13 @@ def qupath_jvm_info_from_qupath_dir(qupath_dir: Path, jvm_options: List[str]) ->
 
 
 # stores qupath version to handle consecutive calls to start_jvm
-_QUPATH_VERSION: Union[Version, LegacyVersion, None] = None
+_QUPATH_VERSION: Optional[QuPathVersion] = None
 
 
 def start_jvm(
     finder: Optional[Callable[..., QuPathJVMInfo]] = None,
     finder_kwargs: Optional[Dict[str, Any]] = None,
-) -> Union[Version, LegacyVersion, None]:
+) -> Optional[QuPathVersion]:
     """start the jvm via jpype
 
     This is automatically called at import of `paquo.java`.
@@ -167,6 +173,7 @@ def start_jvm(
     # For the time being, we assume qupath is our JVM of choice
     app_dir, runtime_dir, jvm_path, jvm_options = finder(**finder_kwargs)
 
+    patched_env: Callable[[], ContextManager[Any]]
     if platform.system() == "Windows":
         # workaround for EXCEPTION_ACCESS_VIOLATION crash
         # see: https://github.com/bayer-science-for-a-better-life/paquo/issues/67
@@ -244,5 +251,5 @@ def start_jvm(
     except (TypeError, AttributeError):  # pragma: no cover
         version = _QUPATH_VERSION = None
     else:
-        version = _QUPATH_VERSION = parse(_version)
+        version = _QUPATH_VERSION = QuPathVersion(_version)
     return version
