@@ -3,8 +3,11 @@ import math
 import pathlib
 import re
 import shutil
+import sys
 from contextlib import contextmanager
 from typing import Any
+from typing import Callable
+from typing import ContextManager
 from typing import Dict
 from typing import Hashable
 from typing import Iterable
@@ -15,15 +18,16 @@ from typing import Tuple
 from typing import Union
 from typing import overload
 
-try:
-    from typing import Literal  # type: ignore
-except ImportError:
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
     from typing_extensions import Literal
 
 from paquo import settings
 from paquo._logging import get_logger
 from paquo._logging import redirect
 from paquo._utils import make_backup_filename
+from paquo._utils import nullcontext
 from paquo.classes import QuPathPathClass
 from paquo.images import ImageProvider
 from paquo.images import QuPathImageType
@@ -44,6 +48,8 @@ from paquo.java import ProjectIO
 from paquo.java import Projects
 from paquo.java import ServerTools
 from paquo.java import String
+from paquo.java import compatibility
+
 
 _log = get_logger(__name__)
 
@@ -163,16 +169,7 @@ def _stash_project_files(project_dir: pathlib.Path):
 DEFAULT_IMAGE_PROVIDER: Any = SimpleURIImageProvider()
 
 
-ProjectIOMode = Union[
-    Literal["r"],
-    Literal["r+"],
-    Literal["w"],
-    Literal["w+"],
-    Literal["a"],
-    Literal["a+"],
-    Literal["x"],
-    Literal["x+"],
-]
+ProjectIOMode = Literal["r", "r+", "w", "w+", "a", "a+", "x", "x+"]
 
 
 class QuPathProject:
@@ -228,7 +225,23 @@ class QuPathProject:
             _exists = False
 
         if _exists:
-            with redirect(stderr=True, stdout=True):
+            cm: Callable[..., ContextManager[Any]]
+            if compatibility.requires_missing_classes_json_fix():
+                @contextmanager
+                def cm(is_readonly):
+                    classes_json = p.parent.joinpath("classifiers", "classes.json")
+                    is_missing = not classes_json.is_file()
+                    if is_missing:
+                        classes_json.write_text('{"pathClasses":[]}')
+                    try:
+                        yield
+                    finally:
+                        if is_missing and is_readonly:
+                            classes_json.unlink(missing_ok=True)
+            else:
+                cm = nullcontext
+
+            with redirect(stderr=True, stdout=True), cm(self._readonly):
                 project = ProjectIO.loadProject(File(str(p)), BufferedImage)
         else:
             p_dir = p.parent
@@ -262,7 +275,7 @@ class QuPathProject:
             # update the proxy
             self._image_entries_proxy.refresh()
 
-    @redirect(stderr=True, stdout=True)  # type: ignore
+    @redirect(stderr=True, stdout=True)
     def add_image(self,
                   image_id: Any,  # this should actually be ID type of the image provider
                   image_type: Optional[QuPathImageType] = None,
